@@ -7,13 +7,13 @@ use v5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.3.0';
+our $VERSION = 'v0.3.1';
 
 use Carp;
 use Const::Fast;
 use Exporter ();
 use Package::Stash;
-use Ref::Util qw/ is_blessed_ref is_plain_arrayref is_ref /;
+use Ref::Util qw/ is_blessed_ref is_arrayref is_coderef is_ref /;
 
 # RECOMMEND PREREQ: Package::Stash::XS
 # RECOMMEND PREREQ: Ref::Util::XS
@@ -37,6 +37,9 @@ sub import {
     $stash->add_symbol( '&import', \&Exporter::import )
       unless ( $stash->has_symbol('&import') );
 
+    _add_symbol( $stash, 'const', \&Const::Fast::const );
+    _export_symbol( $stash, 'const' );
+
     while ( my $tag = shift ) {
 
         croak "'${tag}' is reserved" if $tag eq 'all';
@@ -44,15 +47,15 @@ sub import {
         my $defs = shift;
 
         croak "An array reference required for tag '${tag}'"
-            unless is_plain_arrayref($defs);
+          unless is_arrayref($defs);
 
         while ( my $item = shift @{$defs} ) {
 
-            for ( $item ) {
+            for ($item) {
 
                 # Array reference means a list of enumerated symbols
 
-                if (is_plain_arrayref($_)) {
+                if ( is_arrayref($_) ) {
 
                     my @enums = @{$item};
                     my $start = shift @{$defs};
@@ -78,7 +81,7 @@ sub import {
 
                 # A scalar is a name of a symbol
 
-                if (!is_ref($_)) {
+                if ( !is_ref($_) ) {
 
                     my $symbol = $item;
                     my $sigil  = _get_sigil($symbol);
@@ -157,7 +160,8 @@ sub _add_symbol {
     }
     else {
 
-        $stash->add_symbol( '&' . $symbol, sub { $value } );
+        $stash->add_symbol( '&' . $symbol,
+            is_coderef($value) ? $value : sub { $value } );
 
     }
 }
@@ -170,6 +174,8 @@ sub _export_symbol {
     my $export_ok   = $stash->get_symbol('@EXPORT_OK');
     my $export_tags = $stash->get_symbol('%EXPORT_TAGS');
 
+    $tag //= 'all';
+
     $export_tags->{$tag} //= [];
 
     push @{ $export_tags->{$tag} }, $symbol;
@@ -227,7 +233,7 @@ Const::Exporter - Declare constants for export.
 
 =head1 VERSION
 
-version v0.3.0
+version v0.3.1
 
 =head1 SYNOPSIS
 
@@ -235,8 +241,6 @@ Define a constants module:
 
   package MyApp::Constants;
 
-  use Const::Fast;
-
   our $zoo => 1234;
 
   use Const::Exporter
